@@ -7,7 +7,7 @@ from django.db import models, transaction
 from django.db.models.signals import pre_delete
 from django.dispatch import receiver
 from django.utils.module_loading import import_by_path
-from manager_utils import sync
+from manager_utils import sync, ManagerUtilsManager
 
 from jsonfield import JSONField
 
@@ -17,6 +17,9 @@ class SmartManager(models.Model):
     Specifies the template, its associated model template class, and whether or not deletions should
     be managed by this model template.
     """
+    # A unique identifier to load smart managers by name
+    name = models.CharField(max_length=128, unique=True)
+
     # The loadable model template class that inherits BaseSmartManager
     smart_manager_class = models.CharField(max_length=128)
 
@@ -27,6 +30,11 @@ class SmartManager(models.Model):
     # The template of the model(s) being managed
     template = JSONField()
 
+    objects = ManagerUtilsManager()
+
+    def __unicode__(self):
+        return self.name
+
     def clean(self):
         """
         Verify that the object can be built and the template class can be loaded. If any exception happens, raise
@@ -83,5 +91,11 @@ def delete_model_obj_on_smart_manager_object_delete(sender, instance, **kwargs):
     If the model template is managing deletions, delete all of the model objects associated with it before
     the template is deleted.
     """
-    if instance.smart_manager.manages_deletions and instance.model_obj:
-        instance.model_obj.delete()
+    if instance.smart_manager.manages_deletions:
+        try:
+            instance.model_obj.delete()
+        except:
+            # The model object could have been deleteed. Its ctype could have been corrupted. It could
+            # have also been trying to cascade delete a protected model. Ignore any deletion errors with
+            # model objects.
+            pass
