@@ -2,8 +2,8 @@ from django.core.exceptions import ValidationError
 from django.test import TestCase, TransactionTestCase
 from django_dynamic_fixture import G, N
 
-from smart_manager import SmartManager
-from smart_manager.tests.models import UpsertModel
+from smart_manager.models import SmartManager, SmartManagerObject
+from smart_manager.tests.models import UpsertModel, RelModel, CantCascadeModel
 
 
 class ValidationTest(TransactionTestCase):
@@ -57,6 +57,43 @@ class SmartManagerTest(TestCase):
     """
     Tests custom functionality in the SmartManager class.
     """
+    def test_unicode(self):
+        smart_manager = SmartManager(name='hi')
+        self.assertEquals(smart_manager.__unicode__(), 'hi')
+
+    def test_undeletable_object(self):
+        """
+        Tests deleting elements from the template of a smart manager when the elements are not
+        deletable.
+        """
+        smart_manager = G(
+            SmartManager,
+            manages_deletions=True,
+            smart_manager_class='smart_manager.tests.smart_managers.DontDeleteUpsertSmartManager',
+            template={
+                'char_field': 'hi',
+                'int_field': 1,
+            },
+        )
+
+        self.assertEquals(UpsertModel.objects.count(), 1)
+        self.assertTrue(UpsertModel.objects.filter(char_field='hi', int_field=1).exists())
+
+        # All objects should still exist even after deleting them from the template and deleting the
+        # smart manager itself
+        smart_manager.template = {
+            'char_field': 'hello',
+            'int_field': 2,
+        }
+        smart_manager.save()
+
+        self.assertEquals(UpsertModel.objects.count(), 2)
+        self.assertTrue(UpsertModel.objects.filter(char_field='hi', int_field=1).exists())
+        self.assertTrue(UpsertModel.objects.filter(char_field='hello', int_field=2).exists())
+
+        smart_manager.delete()
+        self.assertEquals(UpsertModel.objects.count(), 2)
+
     def test_template_changes(self):
         """
         Tests chaning the template and resaving.
@@ -171,6 +208,31 @@ class SmartManagerTest(TestCase):
         smart_manager.delete()
         self.assertFalse(UpsertModel.objects.exists())
 
+    def test_deletion_protected_model(self):
+        """
+        Tests when a cascade delete cant occur becasue of a protected model.
+        """
+        rel_model = G(RelModel)
+        G(CantCascadeModel, rel_model=rel_model)
+
+        smart_manager = G(
+            SmartManager,
+            manages_deletions=True,
+            smart_manager_class='smart_manager.tests.smart_managers.UpsertSmartManager',
+            template={
+                'char_field': 'hi',
+                'int_field': 1,
+            },
+        )
+        SmartManagerObject.objects.create(smart_manager=smart_manager, model_obj=rel_model)
+
+        smart_manager.delete()
+
+        # The rel model should still exist since its protected. The smart manager object
+        # should not
+        self.assertFalse(SmartManagerObject.objects.exists())
+        self.assertTrue(RelModel.objects.exists())
+
     def test_deletion_valid_obj_deletions_set(self):
         """
         Tests deletion of a valid object when deletions are set.
